SetWindowTitlePlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • SetWindowTitlePlatform
Implementers

Constructors

SetWindowTitlePlatform()
Constructs a SetWindowTitlePlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setTitle(String title) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance SetWindowTitlePlatform
The default instance of SetWindowTitlePlatform to use.
getter/setter pair